@@ -252,13 +252,14 @@ impl GossipService {
             if !self.cache.contains_key(&MessageKey::from_inner(message.id)) {
                 if *src != self.address {
                     // TODO: Only print if the protocol id is "chat"
-                    println!("Received message from {:?}", src);
-                    let string = String::from_utf8_lossy(&message.data);
-                    println!("{:?}", string);
+                    info!("Received message from {:?}", src);
                 }
                 let key = MessageKey::from_inner(message.id);
                 self.publish(src, msg.clone());
                 self.cache.entry(key).or_insert((msg.clone(), Instant::now()));
+                if let Err(e) = self.to_app_tx.send(message) {
+                    info!("Error sending message to application layer: {:?}", e)
+                }
             }
         }
     }
